DEVICONS_GLYPHS_LOADED=1
DEVICONS_GLYPHS_VERSION='1.8.0'
CODEPOINT_OF_DEVICONS_GIT='e602'
CODEPOINT_OF_DEVICONS_GIT_COMPARE='e628'
CODEPOINT_OF_DEVICONS_GIT_BRANCH='e625'
CODEPOINT_OF_DEVICONS_GIT_COMMIT='e629'
CODEPOINT_OF_DEVICONS_GIT_PULL_REQUEST='e626'
CODEPOINT_OF_DEVICONS_GIT_MERGE='e627'
CODEPOINT_OF_DEVICONS_BITBUCKET='e603'
CODEPOINT_OF_DEVICONS_GITHUB_ALT='e608'
CODEPOINT_OF_DEVICONS_GITHUB_BADGE='e609'
CODEPOINT_OF_DEVICONS_GITHUB='e60a'
CODEPOINT_OF_DEVICONS_GITHUB_FULL='e617'
CODEPOINT_OF_DEVICONS_JAVA='e638'
CODEPOINT_OF_DEVICONS_RUBY='e639'
CODEPOINT_OF_DEVICONS_SCALA='e637'
CODEPOINT_OF_DEVICONS_PYTHON='e63c'
CODEPOINT_OF_DEVICONS_GO='e624'
CODEPOINT_OF_DEVICONS_RUBY_ON_RAILS='e63b'
CODEPOINT_OF_DEVICONS_DJANGO='e61d'
CODEPOINT_OF_DEVICONS_MARKDOWN='e63e'
CODEPOINT_OF_DEVICONS_PHP='e63d'
CODEPOINT_OF_DEVICONS_MYSQL='e604'
CODEPOINT_OF_DEVICONS_STREAMLINE='e605'
CODEPOINT_OF_DEVICONS_DATABASE='e606'
CODEPOINT_OF_DEVICONS_LARAVEL='e63f'
CODEPOINT_OF_DEVICONS_JAVASCRIPT='e64e'
CODEPOINT_OF_DEVICONS_ANGULAR='e653'
CODEPOINT_OF_DEVICONS_BACKBONE='e652'
CODEPOINT_OF_DEVICONS_COFFEESCRIPT='e651'
CODEPOINT_OF_DEVICONS_JQUERY='e650'
CODEPOINT_OF_DEVICONS_MODERNIZR='e620'
CODEPOINT_OF_DEVICONS_JQUERY_UI='e654'
CODEPOINT_OF_DEVICONS_EMBER='e61b'
CODEPOINT_OF_DEVICONS_DOJO='e61c'
CODEPOINT_OF_DEVICONS_NODEJS='e619'
CODEPOINT_OF_DEVICONS_NODEJS_SMALL='e618'
CODEPOINT_OF_DEVICONS_JAVASCRIPT_SHIELD='e64f'
CODEPOINT_OF_DEVICONS_BOOTSTRAP='e647'
CODEPOINT_OF_DEVICONS_SASS='e64b'
CODEPOINT_OF_DEVICONS_CSS3_FULL='e64a'
CODEPOINT_OF_DEVICONS_CSS3='e649'
CODEPOINT_OF_DEVICONS_HTML5='e636'
CODEPOINT_OF_DEVICONS_HTML5_MULTIMEDIA='e632'
CODEPOINT_OF_DEVICONS_HTML5_DEVICE_ACCESS='e633'
CODEPOINT_OF_DEVICONS_HTML5_3D_EFFECTS='e635'
CODEPOINT_OF_DEVICONS_HTML5_CONNECTIVITY='e634'
CODEPOINT_OF_DEVICONS_GHOST_SMALL='e614'
CODEPOINT_OF_DEVICONS_GHOST='e61f'
CODEPOINT_OF_DEVICONS_MAGENTO='e640'
CODEPOINT_OF_DEVICONS_JOOMLA='e641'
CODEPOINT_OF_DEVICONS_JEKYLL_SMALL='e60d'
CODEPOINT_OF_DEVICONS_DRUPAL='e642'
CODEPOINT_OF_DEVICONS_WORDPRESS='e60b'
CODEPOINT_OF_DEVICONS_GRUNT='e64c'
CODEPOINT_OF_DEVICONS_BOWER='e64d'
CODEPOINT_OF_DEVICONS_NPM='e61e'
CODEPOINT_OF_DEVICONS_YAHOO_SMALL='e62b'
CODEPOINT_OF_DEVICONS_YAHOO='e615'
CODEPOINT_OF_DEVICONS_BING_SMALL='e600'
CODEPOINT_OF_DEVICONS_WINDOWS='e60f'
CODEPOINT_OF_DEVICONS_LINUX='e612'
CODEPOINT_OF_DEVICONS_UBUNTU='e63a'
CODEPOINT_OF_DEVICONS_ANDROID='e60e'
CODEPOINT_OF_DEVICONS_APPLE='e611'
CODEPOINT_OF_DEVICONS_APPSTORE='e613'
CODEPOINT_OF_DEVICONS_PHONEGAP='e630'
CODEPOINT_OF_DEVICONS_BLACKBERRY='e623'
CODEPOINT_OF_DEVICONS_STACKOVERFLOW='e610'
CODEPOINT_OF_DEVICONS_TECHCRUNCH='e62c'
CODEPOINT_OF_DEVICONS_CODROPS='e62f'
CODEPOINT_OF_DEVICONS_CSS_TRICKS='e601'
CODEPOINT_OF_DEVICONS_SMASHING_MAGAZINE='e62d'
CODEPOINT_OF_DEVICONS_NETMAGAZINE='e62e'
CODEPOINT_OF_DEVICONS_CODEPEN='e616'
CODEPOINT_OF_DEVICONS_CSSDECK='e62a'
CODEPOINT_OF_DEVICONS_HACKERNEWS='e61a'
CODEPOINT_OF_DEVICONS_DROPBOX='e607'
CODEPOINT_OF_DEVICONS_GOOGLE_DRIVE='e631'
CODEPOINT_OF_DEVICONS_VISUALSTUDIO='e60c'
CODEPOINT_OF_DEVICONS_UNITY_SMALL='e621'
CODEPOINT_OF_DEVICONS_RASPBERRY_PI='e622'
CODEPOINT_OF_DEVICONS_CHROME='e643'
CODEPOINT_OF_DEVICONS_IE='e644'
CODEPOINT_OF_DEVICONS_FIREFOX='e645'
CODEPOINT_OF_DEVICONS_OPERA='e646'
CODEPOINT_OF_DEVICONS_SAFARI='e648'
CODEPOINT_OF_DEVICONS_SWIFT='e655'
CODEPOINT_OF_DEVICONS_SYMFONY='e656'
CODEPOINT_OF_DEVICONS_SYMFONY_BADGE='e657'
CODEPOINT_OF_DEVICONS_LESS='e658'
CODEPOINT_OF_DEVICONS_STYLUS='e659'
CODEPOINT_OF_DEVICONS_TRELLO='e65a'
CODEPOINT_OF_DEVICONS_ATLASSIAN='e65b'
CODEPOINT_OF_DEVICONS_JIRA='e65c'
CODEPOINT_OF_DEVICONS_ENVATO='e65d'
CODEPOINT_OF_DEVICONS_SNAP_SVG='e65e'
CODEPOINT_OF_DEVICONS_RAPHAEL='e65f'
CODEPOINT_OF_DEVICONS_GOOGLE_ANALYTICS='e660'
CODEPOINT_OF_DEVICONS_COMPASS='e661'
CODEPOINT_OF_DEVICONS_ONEDRIVE='e662'
CODEPOINT_OF_DEVICONS_GULP='e663'
CODEPOINT_OF_DEVICONS_ATOM='e664'
CODEPOINT_OF_DEVICONS_CISCO='e665'
CODEPOINT_OF_DEVICONS_NANCY='e666'
CODEPOINT_OF_DEVICONS_CLOJURE='e668'
CODEPOINT_OF_DEVICONS_CLOJURE_ALT='e66a'
CODEPOINT_OF_DEVICONS_PERL='e669'
CODEPOINT_OF_DEVICONS_CELLULOID='e66b'
CODEPOINT_OF_DEVICONS_W3C='e66c'
CODEPOINT_OF_DEVICONS_REDIS='e66d'
CODEPOINT_OF_DEVICONS_POSTGRESQL='e66e'
CODEPOINT_OF_DEVICONS_WEBPLATFORM='e66f'
CODEPOINT_OF_DEVICONS_JENKINS='e667'
CODEPOINT_OF_DEVICONS_REQUIREJS='e670'
CODEPOINT_OF_DEVICONS_OPENSOURCE='e671'
CODEPOINT_OF_DEVICONS_TYPO3='e672'
CODEPOINT_OF_DEVICONS_UIKIT='e673'
CODEPOINT_OF_DEVICONS_DOCTRINE='e674'
CODEPOINT_OF_DEVICONS_GROOVY='e675'
CODEPOINT_OF_DEVICONS_NGINX='e676'
CODEPOINT_OF_DEVICONS_HASKELL='e677'
CODEPOINT_OF_DEVICONS_ZEND='e678'
CODEPOINT_OF_DEVICONS_GNU='e679'
CODEPOINT_OF_DEVICONS_YEOMAN='e67a'
CODEPOINT_OF_DEVICONS_HEROKU='e67b'
CODEPOINT_OF_DEVICONS_DEBIAN='e67d'
CODEPOINT_OF_DEVICONS_TRAVIS='e67e'
CODEPOINT_OF_DEVICONS_DOTNET='e67f'
CODEPOINT_OF_DEVICONS_CODEIGNITER='e680'
CODEPOINT_OF_DEVICONS_JAVASCRIPT_BADGE='e681'
CODEPOINT_OF_DEVICONS_YII='e682'
CODEPOINT_OF_DEVICONS_MSQL_SERVER='e67c'
CODEPOINT_OF_DEVICONS_COMPOSER='e683'
CODEPOINT_OF_DEVICONS_KRAKENJS_BADGE='e684'
CODEPOINT_OF_DEVICONS_KRAKENJS='e685'
CODEPOINT_OF_DEVICONS_MOZILLA='e686'
CODEPOINT_OF_DEVICONS_FIREBASE='e687'
CODEPOINT_OF_DEVICONS_SIZZLEJS='e688'
CODEPOINT_OF_DEVICONS_CREATIVECOMMONS='e689'
CODEPOINT_OF_DEVICONS_CREATIVECOMMONS_BADGE='e68a'
CODEPOINT_OF_DEVICONS_MITLICENCE='e68b'
CODEPOINT_OF_DEVICONS_SENCHATOUCH='e68c'
CODEPOINT_OF_DEVICONS_BUGSENSE='e68d'
CODEPOINT_OF_DEVICONS_EXTJS='e68e'
CODEPOINT_OF_DEVICONS_MOOTOOLS_BADGE='e68f'
CODEPOINT_OF_DEVICONS_MOOTOOLS='e690'
CODEPOINT_OF_DEVICONS_RUBY_ROUGH='e691'
CODEPOINT_OF_DEVICONS_KOMODO='e692'
CODEPOINT_OF_DEVICONS_CODA='e693'
CODEPOINT_OF_DEVICONS_BINTRAY='e694'
CODEPOINT_OF_DEVICONS_TERMINAL='e695'
CODEPOINT_OF_DEVICONS_CODE='e696'
CODEPOINT_OF_DEVICONS_RESPONSIVE='e697'
CODEPOINT_OF_DEVICONS_DART='e698'
CODEPOINT_OF_DEVICONS_APTANA='e699'
CODEPOINT_OF_DEVICONS_MAILCHIMP='e69a'
CODEPOINT_OF_DEVICONS_NETBEANS='e69b'
CODEPOINT_OF_DEVICONS_DREAMWEAVER='e69c'
CODEPOINT_OF_DEVICONS_BRACKETS='e69d'
CODEPOINT_OF_DEVICONS_ECLIPSE='e69e'
CODEPOINT_OF_DEVICONS_CLOUD9='e69f'
CODEPOINT_OF_DEVICONS_SCRUM='e6a0'
CODEPOINT_OF_DEVICONS_PROLOG='e6a1'
CODEPOINT_OF_DEVICONS_TERMINAL_BADGE='e6a2'
CODEPOINT_OF_DEVICONS_CODE_BADGE='e6a3'
CODEPOINT_OF_DEVICONS_MONGODB='e6a4'
CODEPOINT_OF_DEVICONS_METEOR='e6a5'
CODEPOINT_OF_DEVICONS_METEORFULL='e6a6'
CODEPOINT_OF_DEVICONS_FSHARP='e6a7'
CODEPOINT_OF_DEVICONS_RUST='e6a8'
CODEPOINT_OF_DEVICONS_IONIC='e6a9'
CODEPOINT_OF_DEVICONS_SUBLIME='e6aa'
CODEPOINT_OF_DEVICONS_APPCELERATOR='e6ab'
CODEPOINT_OF_DEVICONS_ASTERISK='e6ac'
CODEPOINT_OF_DEVICONS_AWS='e6ad'
CODEPOINT_OF_DEVICONS_DIGITAL_OCEAN='e6ae'
CODEPOINT_OF_DEVICONS_DLANG='e6af'
CODEPOINT_OF_DEVICONS_DOCKER='e6b0'
CODEPOINT_OF_DEVICONS_ERLANG='e6b1'
CODEPOINT_OF_DEVICONS_GOOGLE_CLOUD_PLATFORM='e6b2'
CODEPOINT_OF_DEVICONS_GRAILS='e6b3'
CODEPOINT_OF_DEVICONS_ILLUSTRATOR='e6b4'
CODEPOINT_OF_DEVICONS_INTELLIJ='e6b5'
CODEPOINT_OF_DEVICONS_MATERIALIZECSS='e6b6'
CODEPOINT_OF_DEVICONS_OPENSHIFT='e6b7'
CODEPOINT_OF_DEVICONS_PHOTOSHOP='e6b8'
CODEPOINT_OF_DEVICONS_RACKSPACE='e6b9'
CODEPOINT_OF_DEVICONS_REACT='e6ba'
CODEPOINT_OF_DEVICONS_REDHAT='e6bb'
CODEPOINT_OF_DEVICONS_SCRIPTCS='e6bc'
CODEPOINT_OF_DEVICONS_SQLLITE='e6c4'
CODEPOINT_OF_DEVICONS_VIM='e6c5'
