POMICONS_GLYPHS_LOADED=1
POMICONS_GLYPHS_VERSION='1.0.0'
CODEPOINT_OF_POMICONS_CLEAN_CODE='e000'
CODEPOINT_OF_POMICONS_POMODORO_DONE='e001'
CODEPOINT_OF_POMICONS_POMODORO_ESTIMATED='e002'
CODEPOINT_OF_POMICONS_POMODORO_TICKING='e003'
CODEPOINT_OF_POMICONS_POMODORO_SQUASHED='e004'
CODEPOINT_OF_POMICONS_LONG_PAUSE='e005'
CODEPOINT_OF_POMICONS_AWAY='e006'
CODEPOINT_OF_POMICONS_PAIR_PROGRAMMING='e007'
