AWESOME_GLYPHS_LOADED=1
AWESOME_GLYPHS_VERSION='4.7.0'
CODEPOINT_OF_AWESOME_500PX='f26e'
CODEPOINT_OF_AWESOME_ADDRESS_BOOK='f2b9'
CODEPOINT_OF_AWESOME_ADDRESS_BOOK_O='f2ba'
CODEPOINT_OF_AWESOME_ADDRESS_CARD='f2bb'
CODEPOINT_OF_AWESOME_ADDRESS_CARD_O='f2bc'
CODEPOINT_OF_AWESOME_ADJUST='f042'
CODEPOINT_OF_AWESOME_ADN='f170'
CODEPOINT_OF_AWESOME_ALIGN_CENTER='f037'
CODEPOINT_OF_AWESOME_ALIGN_JUSTIFY='f039'
CODEPOINT_OF_AWESOME_ALIGN_LEFT='f036'
CODEPOINT_OF_AWESOME_ALIGN_RIGHT='f038'
CODEPOINT_OF_AWESOME_AMAZON='f270'
CODEPOINT_OF_AWESOME_AMBULANCE='f0f9'
CODEPOINT_OF_AWESOME_AMERICAN_SIGN_LANGUAGE_INTERPRETING='f2a3'
CODEPOINT_OF_AWESOME_ANCHOR='f13d'
CODEPOINT_OF_AWESOME_ANDROID='f17b'
CODEPOINT_OF_AWESOME_ANGELLIST='f209'
CODEPOINT_OF_AWESOME_ANGLE_DOUBLE_DOWN='f103'
CODEPOINT_OF_AWESOME_ANGLE_DOUBLE_LEFT='f100'
CODEPOINT_OF_AWESOME_ANGLE_DOUBLE_RIGHT='f101'
CODEPOINT_OF_AWESOME_ANGLE_DOUBLE_UP='f102'
CODEPOINT_OF_AWESOME_ANGLE_DOWN='f107'
CODEPOINT_OF_AWESOME_ANGLE_LEFT='f104'
CODEPOINT_OF_AWESOME_ANGLE_RIGHT='f105'
CODEPOINT_OF_AWESOME_ANGLE_UP='f106'
CODEPOINT_OF_AWESOME_APPLE='f179'
CODEPOINT_OF_AWESOME_ARCHIVE='f187'
CODEPOINT_OF_AWESOME_AREA_CHART='f1fe'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_DOWN='f0ab'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_LEFT='f0a8'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_O_DOWN='f01a'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_O_LEFT='f190'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_O_RIGHT='f18e'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_O_UP='f01b'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_RIGHT='f0a9'
CODEPOINT_OF_AWESOME_ARROW_CIRCLE_UP='f0aa'
CODEPOINT_OF_AWESOME_ARROW_DOWN='f063'
CODEPOINT_OF_AWESOME_ARROW_LEFT='f060'
CODEPOINT_OF_AWESOME_ARROW_RIGHT='f061'
CODEPOINT_OF_AWESOME_ARROW_UP='f062'
CODEPOINT_OF_AWESOME_ARROWS='f047'
CODEPOINT_OF_AWESOME_ARROWS_ALT='f0b2'
CODEPOINT_OF_AWESOME_ARROWS_H='f07e'
CODEPOINT_OF_AWESOME_ARROWS_V='f07d'
CODEPOINT_OF_AWESOME_ASL_INTERPRETING='f2a3'
CODEPOINT_OF_AWESOME_ASSISTIVE_LISTENING_SYSTEMS='f2a2'
CODEPOINT_OF_AWESOME_ASTERISK='f069'
CODEPOINT_OF_AWESOME_AT='f1fa'
CODEPOINT_OF_AWESOME_AUDIO_DESCRIPTION='f29e'
CODEPOINT_OF_AWESOME_AUTOMOBILE='f1b9'
CODEPOINT_OF_AWESOME_BACKWARD='f04a'
CODEPOINT_OF_AWESOME_BALANCE_SCALE='f24e'
CODEPOINT_OF_AWESOME_BAN='f05e'
CODEPOINT_OF_AWESOME_BANDCAMP='f2d5'
CODEPOINT_OF_AWESOME_BANK='f19c'
CODEPOINT_OF_AWESOME_BAR_CHART='f080'
CODEPOINT_OF_AWESOME_BAR_CHART_O='f080'
CODEPOINT_OF_AWESOME_BARCODE='f02a'
CODEPOINT_OF_AWESOME_BARS='f0c9'
CODEPOINT_OF_AWESOME_BATH='f2cd'
CODEPOINT_OF_AWESOME_BATHTUB='f2cd'
CODEPOINT_OF_AWESOME_BATTERY='f240'
CODEPOINT_OF_AWESOME_BATTERY_0='f244'
CODEPOINT_OF_AWESOME_BATTERY_1='f243'
CODEPOINT_OF_AWESOME_BATTERY_2='f242'
CODEPOINT_OF_AWESOME_BATTERY_3='f241'
CODEPOINT_OF_AWESOME_BATTERY_4='f240'
CODEPOINT_OF_AWESOME_BATTERY_EMPTY='f244'
CODEPOINT_OF_AWESOME_BATTERY_FULL='f240'
CODEPOINT_OF_AWESOME_BATTERY_HALF='f242'
CODEPOINT_OF_AWESOME_BATTERY_QUARTER='f243'
CODEPOINT_OF_AWESOME_BATTERY_THREE_QUARTERS='f241'
CODEPOINT_OF_AWESOME_BED='f236'
CODEPOINT_OF_AWESOME_BEER='f0fc'
CODEPOINT_OF_AWESOME_BEHANCE='f1b4'
CODEPOINT_OF_AWESOME_BEHANCE_SQUARE='f1b5'
CODEPOINT_OF_AWESOME_BELL='f0f3'
CODEPOINT_OF_AWESOME_BELL_O='f0a2'
CODEPOINT_OF_AWESOME_BELL_SLASH='f1f6'
CODEPOINT_OF_AWESOME_BELL_SLASH_O='f1f7'
CODEPOINT_OF_AWESOME_BICYCLE='f206'
CODEPOINT_OF_AWESOME_BINOCULARS='f1e5'
CODEPOINT_OF_AWESOME_BIRTHDAY_CAKE='f1fd'
CODEPOINT_OF_AWESOME_BITBUCKET='f171'
CODEPOINT_OF_AWESOME_BITBUCKET_SQUARE='f172'
CODEPOINT_OF_AWESOME_BITCOIN='f15a'
CODEPOINT_OF_AWESOME_BLACK_TIE='f27e'
CODEPOINT_OF_AWESOME_BLIND='f29d'
CODEPOINT_OF_AWESOME_BLUETOOTH='f293'
CODEPOINT_OF_AWESOME_BLUETOOTH_B='f294'
CODEPOINT_OF_AWESOME_BOLD='f032'
CODEPOINT_OF_AWESOME_BOLT='f0e7'
CODEPOINT_OF_AWESOME_BOMB='f1e2'
CODEPOINT_OF_AWESOME_BOOK='f02d'
CODEPOINT_OF_AWESOME_BOOKMARK='f02e'
CODEPOINT_OF_AWESOME_BOOKMARK_O='f097'
CODEPOINT_OF_AWESOME_BRAILLE='f2a1'
CODEPOINT_OF_AWESOME_BRIEFCASE='f0b1'
CODEPOINT_OF_AWESOME_BTC='f15a'
CODEPOINT_OF_AWESOME_BUG='f188'
CODEPOINT_OF_AWESOME_BUILDING='f1ad'
CODEPOINT_OF_AWESOME_BUILDING_O='f0f7'
CODEPOINT_OF_AWESOME_BULLHORN='f0a1'
CODEPOINT_OF_AWESOME_BULLSEYE='f140'
CODEPOINT_OF_AWESOME_BUS='f207'
CODEPOINT_OF_AWESOME_BUYSELLADS='f20d'
CODEPOINT_OF_AWESOME_CAB='f1ba'
CODEPOINT_OF_AWESOME_CALCULATOR='f1ec'
CODEPOINT_OF_AWESOME_CALENDAR='f073'
CODEPOINT_OF_AWESOME_CALENDAR_CHECK_O='f274'
CODEPOINT_OF_AWESOME_CALENDAR_MINUS_O='f272'
CODEPOINT_OF_AWESOME_CALENDAR_O='f133'
CODEPOINT_OF_AWESOME_CALENDAR_PLUS_O='f271'
CODEPOINT_OF_AWESOME_CALENDAR_TIMES_O='f273'
CODEPOINT_OF_AWESOME_CAMERA='f030'
CODEPOINT_OF_AWESOME_CAMERA_RETRO='f083'
CODEPOINT_OF_AWESOME_CAR='f1b9'
CODEPOINT_OF_AWESOME_CARET_DOWN='f0d7'
CODEPOINT_OF_AWESOME_CARET_LEFT='f0d9'
CODEPOINT_OF_AWESOME_CARET_RIGHT='f0da'
CODEPOINT_OF_AWESOME_CARET_SQUARE_O_DOWN='f150'
CODEPOINT_OF_AWESOME_CARET_SQUARE_O_LEFT='f191'
CODEPOINT_OF_AWESOME_CARET_SQUARE_O_RIGHT='f152'
CODEPOINT_OF_AWESOME_CARET_SQUARE_O_UP='f151'
CODEPOINT_OF_AWESOME_CARET_UP='f0d8'
CODEPOINT_OF_AWESOME_CART_ARROW_DOWN='f218'
CODEPOINT_OF_AWESOME_CART_PLUS='f217'
CODEPOINT_OF_AWESOME_CC='f20a'
CODEPOINT_OF_AWESOME_CC_AMEX='f1f3'
CODEPOINT_OF_AWESOME_CC_DINERS_CLUB='f24c'
CODEPOINT_OF_AWESOME_CC_DISCOVER='f1f2'
CODEPOINT_OF_AWESOME_CC_JCB='f24b'
CODEPOINT_OF_AWESOME_CC_MASTERCARD='f1f1'
CODEPOINT_OF_AWESOME_CC_PAYPAL='f1f4'
CODEPOINT_OF_AWESOME_CC_STRIPE='f1f5'
CODEPOINT_OF_AWESOME_CC_VISA='f1f0'
CODEPOINT_OF_AWESOME_CERTIFICATE='f0a3'
CODEPOINT_OF_AWESOME_CHAIN='f0c1'
CODEPOINT_OF_AWESOME_CHAIN_BROKEN='f127'
CODEPOINT_OF_AWESOME_CHECK='f00c'
CODEPOINT_OF_AWESOME_CHECK_CIRCLE='f058'
CODEPOINT_OF_AWESOME_CHECK_CIRCLE_O='f05d'
CODEPOINT_OF_AWESOME_CHECK_SQUARE='f14a'
CODEPOINT_OF_AWESOME_CHECK_SQUARE_O='f046'
CODEPOINT_OF_AWESOME_CHEVRON_CIRCLE_DOWN='f13a'
CODEPOINT_OF_AWESOME_CHEVRON_CIRCLE_LEFT='f137'
CODEPOINT_OF_AWESOME_CHEVRON_CIRCLE_RIGHT='f138'
CODEPOINT_OF_AWESOME_CHEVRON_CIRCLE_UP='f139'
CODEPOINT_OF_AWESOME_CHEVRON_DOWN='f078'
CODEPOINT_OF_AWESOME_CHEVRON_LEFT='f053'
CODEPOINT_OF_AWESOME_CHEVRON_RIGHT='f054'
CODEPOINT_OF_AWESOME_CHEVRON_UP='f077'
CODEPOINT_OF_AWESOME_CHILD='f1ae'
CODEPOINT_OF_AWESOME_CHROME='f268'
CODEPOINT_OF_AWESOME_CIRCLE='f111'
CODEPOINT_OF_AWESOME_CIRCLE_O='f10c'
CODEPOINT_OF_AWESOME_CIRCLE_O_NOTCH='f1ce'
CODEPOINT_OF_AWESOME_CIRCLE_THIN='f1db'
CODEPOINT_OF_AWESOME_CLIPBOARD='f0ea'
CODEPOINT_OF_AWESOME_CLOCK_O='f017'
CODEPOINT_OF_AWESOME_CLONE='f24d'
CODEPOINT_OF_AWESOME_CLOSE='f00d'
CODEPOINT_OF_AWESOME_CLOUD='f0c2'
CODEPOINT_OF_AWESOME_CLOUD_DOWNLOAD='f0ed'
CODEPOINT_OF_AWESOME_CLOUD_UPLOAD='f0ee'
CODEPOINT_OF_AWESOME_CNY='f157'
CODEPOINT_OF_AWESOME_CODE='f121'
CODEPOINT_OF_AWESOME_CODE_FORK='f126'
CODEPOINT_OF_AWESOME_CODEPEN='f1cb'
CODEPOINT_OF_AWESOME_CODIEPIE='f284'
CODEPOINT_OF_AWESOME_COFFEE='f0f4'
CODEPOINT_OF_AWESOME_COG='f013'
CODEPOINT_OF_AWESOME_COGS='f085'
CODEPOINT_OF_AWESOME_COLUMNS='f0db'
CODEPOINT_OF_AWESOME_COMMENT='f075'
CODEPOINT_OF_AWESOME_COMMENT_O='f0e5'
CODEPOINT_OF_AWESOME_COMMENTING='f27a'
CODEPOINT_OF_AWESOME_COMMENTING_O='f27b'
CODEPOINT_OF_AWESOME_COMMENTS='f086'
CODEPOINT_OF_AWESOME_COMMENTS_O='f0e6'
CODEPOINT_OF_AWESOME_COMPASS='f14e'
CODEPOINT_OF_AWESOME_COMPRESS='f066'
CODEPOINT_OF_AWESOME_CONNECTDEVELOP='f20e'
CODEPOINT_OF_AWESOME_CONTAO='f26d'
CODEPOINT_OF_AWESOME_COPY='f0c5'
CODEPOINT_OF_AWESOME_COPYRIGHT='f1f9'
CODEPOINT_OF_AWESOME_CREATIVE_COMMONS='f25e'
CODEPOINT_OF_AWESOME_CREDIT_CARD='f09d'
CODEPOINT_OF_AWESOME_CREDIT_CARD_ALT='f283'
CODEPOINT_OF_AWESOME_CROP='f125'
CODEPOINT_OF_AWESOME_CROSSHAIRS='f05b'
CODEPOINT_OF_AWESOME_CSS3='f13c'
CODEPOINT_OF_AWESOME_CUBE='f1b2'
CODEPOINT_OF_AWESOME_CUBES='f1b3'
CODEPOINT_OF_AWESOME_CUT='f0c4'
CODEPOINT_OF_AWESOME_CUTLERY='f0f5'
CODEPOINT_OF_AWESOME_DASHBOARD='f0e4'
CODEPOINT_OF_AWESOME_DASHCUBE='f210'
CODEPOINT_OF_AWESOME_DATABASE='f1c0'
CODEPOINT_OF_AWESOME_DEAF='f2a4'
CODEPOINT_OF_AWESOME_DEAFNESS='f2a4'
CODEPOINT_OF_AWESOME_DEDENT='f03b'
CODEPOINT_OF_AWESOME_DELICIOUS='f1a5'
CODEPOINT_OF_AWESOME_DESKTOP='f108'
CODEPOINT_OF_AWESOME_DEVIANTART='f1bd'
CODEPOINT_OF_AWESOME_DIAMOND='f219'
CODEPOINT_OF_AWESOME_DIGG='f1a6'
CODEPOINT_OF_AWESOME_DOLLAR='f155'
CODEPOINT_OF_AWESOME_DOT_CIRCLE_O='f192'
CODEPOINT_OF_AWESOME_DOWNLOAD='f019'
CODEPOINT_OF_AWESOME_DRIBBBLE='f17d'
CODEPOINT_OF_AWESOME_DRIVERS_LICENSE='f2c2'
CODEPOINT_OF_AWESOME_DRIVERS_LICENSE_O='f2c3'
CODEPOINT_OF_AWESOME_DROPBOX='f16b'
CODEPOINT_OF_AWESOME_DRUPAL='f1a9'
CODEPOINT_OF_AWESOME_EDGE='f282'
CODEPOINT_OF_AWESOME_EDIT='f044'
CODEPOINT_OF_AWESOME_EERCAST='f2da'
CODEPOINT_OF_AWESOME_EJECT='f052'
CODEPOINT_OF_AWESOME_ELLIPSIS_H='f141'
CODEPOINT_OF_AWESOME_ELLIPSIS_V='f142'
CODEPOINT_OF_AWESOME_EMPIRE='f1d1'
CODEPOINT_OF_AWESOME_ENVELOPE='f0e0'
CODEPOINT_OF_AWESOME_ENVELOPE_O='f003'
CODEPOINT_OF_AWESOME_ENVELOPE_OPEN='f2b6'
CODEPOINT_OF_AWESOME_ENVELOPE_OPEN_O='f2b7'
CODEPOINT_OF_AWESOME_ENVELOPE_SQUARE='f199'
CODEPOINT_OF_AWESOME_ENVIRA='f299'
CODEPOINT_OF_AWESOME_ERASER='f12d'
CODEPOINT_OF_AWESOME_ETSY='f2d7'
CODEPOINT_OF_AWESOME_EUR='f153'
CODEPOINT_OF_AWESOME_EURO='f153'
CODEPOINT_OF_AWESOME_EXCHANGE='f0ec'
CODEPOINT_OF_AWESOME_EXCLAMATION='f12a'
CODEPOINT_OF_AWESOME_EXCLAMATION_CIRCLE='f06a'
CODEPOINT_OF_AWESOME_EXCLAMATION_TRIANGLE='f071'
CODEPOINT_OF_AWESOME_EXPAND='f065'
CODEPOINT_OF_AWESOME_EXPEDITEDSSL='f23e'
CODEPOINT_OF_AWESOME_EXTERNAL_LINK='f08e'
CODEPOINT_OF_AWESOME_EXTERNAL_LINK_SQUARE='f14c'
CODEPOINT_OF_AWESOME_EYE='f06e'
CODEPOINT_OF_AWESOME_EYE_SLASH='f070'
CODEPOINT_OF_AWESOME_EYEDROPPER='f1fb'
CODEPOINT_OF_AWESOME_FA='f2b4'
CODEPOINT_OF_AWESOME_FACEBOOK='f09a'
CODEPOINT_OF_AWESOME_FACEBOOK_F='f09a'
CODEPOINT_OF_AWESOME_FACEBOOK_OFFICIAL='f230'
CODEPOINT_OF_AWESOME_FACEBOOK_SQUARE='f082'
CODEPOINT_OF_AWESOME_FAST_BACKWARD='f049'
CODEPOINT_OF_AWESOME_FAST_FORWARD='f050'
CODEPOINT_OF_AWESOME_FAX='f1ac'
CODEPOINT_OF_AWESOME_FEED='f09e'
CODEPOINT_OF_AWESOME_FEMALE='f182'
CODEPOINT_OF_AWESOME_FIGHTER_JET='f0fb'
CODEPOINT_OF_AWESOME_FILE='f15b'
CODEPOINT_OF_AWESOME_FILE_ARCHIVE_O='f1c6'
CODEPOINT_OF_AWESOME_FILE_AUDIO_O='f1c7'
CODEPOINT_OF_AWESOME_FILE_CODE_O='f1c9'
CODEPOINT_OF_AWESOME_FILE_EXCEL_O='f1c3'
CODEPOINT_OF_AWESOME_FILE_IMAGE_O='f1c5'
CODEPOINT_OF_AWESOME_FILE_MOVIE_O='f1c8'
CODEPOINT_OF_AWESOME_FILE_O='f016'
CODEPOINT_OF_AWESOME_FILE_PDF_O='f1c1'
CODEPOINT_OF_AWESOME_FILE_PHOTO_O='f1c5'
CODEPOINT_OF_AWESOME_FILE_PICTURE_O='f1c5'
CODEPOINT_OF_AWESOME_FILE_POWERPOINT_O='f1c4'
CODEPOINT_OF_AWESOME_FILE_SOUND_O='f1c7'
CODEPOINT_OF_AWESOME_FILE_TEXT='f15c'
CODEPOINT_OF_AWESOME_FILE_TEXT_O='f0f6'
CODEPOINT_OF_AWESOME_FILE_VIDEO_O='f1c8'
CODEPOINT_OF_AWESOME_FILE_WORD_O='f1c2'
CODEPOINT_OF_AWESOME_FILE_ZIP_O='f1c6'
CODEPOINT_OF_AWESOME_FILES_O='f0c5'
CODEPOINT_OF_AWESOME_FILM='f008'
CODEPOINT_OF_AWESOME_FILTER='f0b0'
CODEPOINT_OF_AWESOME_FIRE='f06d'
CODEPOINT_OF_AWESOME_FIRE_EXTINGUISHER='f134'
CODEPOINT_OF_AWESOME_FIREFOX='f269'
CODEPOINT_OF_AWESOME_FIRST_ORDER='f2b0'
CODEPOINT_OF_AWESOME_FLAG='f024'
CODEPOINT_OF_AWESOME_FLAG_CHECKERED='f11e'
CODEPOINT_OF_AWESOME_FLAG_O='f11d'
CODEPOINT_OF_AWESOME_FLASH='f0e7'
CODEPOINT_OF_AWESOME_FLASK='f0c3'
CODEPOINT_OF_AWESOME_FLICKR='f16e'
CODEPOINT_OF_AWESOME_FLOPPY_O='f0c7'
CODEPOINT_OF_AWESOME_FOLDER='f07b'
CODEPOINT_OF_AWESOME_FOLDER_O='f114'
CODEPOINT_OF_AWESOME_FOLDER_OPEN='f07c'
CODEPOINT_OF_AWESOME_FOLDER_OPEN_O='f115'
CODEPOINT_OF_AWESOME_FONT='f031'
CODEPOINT_OF_AWESOME_FONT_AWESOME='f2b4'
CODEPOINT_OF_AWESOME_FONTICONS='f280'
CODEPOINT_OF_AWESOME_FORT_AWESOME='f286'
CODEPOINT_OF_AWESOME_FORUMBEE='f211'
CODEPOINT_OF_AWESOME_FORWARD='f04e'
CODEPOINT_OF_AWESOME_FOURSQUARE='f180'
CODEPOINT_OF_AWESOME_FREE_CODE_CAMP='f2c5'
CODEPOINT_OF_AWESOME_FROWN_O='f119'
CODEPOINT_OF_AWESOME_FUTBOL_O='f1e3'
CODEPOINT_OF_AWESOME_GAMEPAD='f11b'
CODEPOINT_OF_AWESOME_GAVEL='f0e3'
CODEPOINT_OF_AWESOME_GBP='f154'
CODEPOINT_OF_AWESOME_GE='f1d1'
CODEPOINT_OF_AWESOME_GEAR='f013'
CODEPOINT_OF_AWESOME_GEARS='f085'
CODEPOINT_OF_AWESOME_GENDERLESS='f22d'
CODEPOINT_OF_AWESOME_GET_POCKET='f265'
CODEPOINT_OF_AWESOME_GG='f260'
CODEPOINT_OF_AWESOME_GG_CIRCLE='f261'
CODEPOINT_OF_AWESOME_GIFT='f06b'
CODEPOINT_OF_AWESOME_GIT='f1d3'
CODEPOINT_OF_AWESOME_GIT_SQUARE='f1d2'
CODEPOINT_OF_AWESOME_GITHUB='f09b'
CODEPOINT_OF_AWESOME_GITHUB_ALT='f113'
CODEPOINT_OF_AWESOME_GITHUB_SQUARE='f092'
CODEPOINT_OF_AWESOME_GITLAB='f296'
CODEPOINT_OF_AWESOME_GITTIP='f184'
CODEPOINT_OF_AWESOME_GLASS='f000'
CODEPOINT_OF_AWESOME_GLIDE='f2a5'
CODEPOINT_OF_AWESOME_GLIDE_G='f2a6'
CODEPOINT_OF_AWESOME_GLOBE='f0ac'
CODEPOINT_OF_AWESOME_GOOGLE='f1a0'
CODEPOINT_OF_AWESOME_GOOGLE_PLUS='f0d5'
CODEPOINT_OF_AWESOME_GOOGLE_PLUS_CIRCLE='f2b3'
CODEPOINT_OF_AWESOME_GOOGLE_PLUS_OFFICIAL='f2b3'
CODEPOINT_OF_AWESOME_GOOGLE_PLUS_SQUARE='f0d4'
CODEPOINT_OF_AWESOME_GOOGLE_WALLET='f1ee'
CODEPOINT_OF_AWESOME_GRADUATION_CAP='f19d'
CODEPOINT_OF_AWESOME_GRATIPAY='f184'
CODEPOINT_OF_AWESOME_GRAV='f2d6'
CODEPOINT_OF_AWESOME_GROUP='f0c0'
CODEPOINT_OF_AWESOME_H_SQUARE='f0fd'
CODEPOINT_OF_AWESOME_HACKER_NEWS='f1d4'
CODEPOINT_OF_AWESOME_HAND_GRAB_O='f255'
CODEPOINT_OF_AWESOME_HAND_LIZARD_O='f258'
CODEPOINT_OF_AWESOME_HAND_O_DOWN='f0a7'
CODEPOINT_OF_AWESOME_HAND_O_LEFT='f0a5'
CODEPOINT_OF_AWESOME_HAND_O_RIGHT='f0a4'
CODEPOINT_OF_AWESOME_HAND_O_UP='f0a6'
CODEPOINT_OF_AWESOME_HAND_PAPER_O='f256'
CODEPOINT_OF_AWESOME_HAND_PEACE_O='f25b'
CODEPOINT_OF_AWESOME_HAND_POINTER_O='f25a'
CODEPOINT_OF_AWESOME_HAND_ROCK_O='f255'
CODEPOINT_OF_AWESOME_HAND_SCISSORS_O='f257'
CODEPOINT_OF_AWESOME_HAND_SPOCK_O='f259'
CODEPOINT_OF_AWESOME_HAND_STOP_O='f256'
CODEPOINT_OF_AWESOME_HANDSHAKE_O='f2b5'
CODEPOINT_OF_AWESOME_HASHTAG='f292'
CODEPOINT_OF_AWESOME_HDD_O='f0a0'
CODEPOINT_OF_AWESOME_HEADER='f1dc'
CODEPOINT_OF_AWESOME_HEADPHONES='f025'
CODEPOINT_OF_AWESOME_HEART='f004'
CODEPOINT_OF_AWESOME_HEART_O='f08a'
CODEPOINT_OF_AWESOME_HEARTBEAT='f21e'
CODEPOINT_OF_AWESOME_HISTORY='f1da'
CODEPOINT_OF_AWESOME_HOME='f015'
CODEPOINT_OF_AWESOME_HOSPITAL_O='f0f8'
CODEPOINT_OF_AWESOME_HOTEL='f236'
CODEPOINT_OF_AWESOME_HOURGLASS='f254'
CODEPOINT_OF_AWESOME_HOURGLASS_1='f251'
CODEPOINT_OF_AWESOME_HOURGLASS_2='f252'
CODEPOINT_OF_AWESOME_HOURGLASS_3='f253'
CODEPOINT_OF_AWESOME_HOURGLASS_END='f253'
CODEPOINT_OF_AWESOME_HOURGLASS_HALF='f252'
CODEPOINT_OF_AWESOME_HOURGLASS_O='f250'
CODEPOINT_OF_AWESOME_HOURGLASS_START='f251'
CODEPOINT_OF_AWESOME_HOUZZ='f27c'
CODEPOINT_OF_AWESOME_HTML5='f13b'
CODEPOINT_OF_AWESOME_I_CURSOR='f246'
CODEPOINT_OF_AWESOME_ID_BADGE='f2c1'
CODEPOINT_OF_AWESOME_ID_CARD='f2c2'
CODEPOINT_OF_AWESOME_ID_CARD_O='f2c3'
CODEPOINT_OF_AWESOME_ILS='f20b'
CODEPOINT_OF_AWESOME_IMAGE='f03e'
CODEPOINT_OF_AWESOME_IMDB='f2d8'
CODEPOINT_OF_AWESOME_INBOX='f01c'
CODEPOINT_OF_AWESOME_INDENT='f03c'
CODEPOINT_OF_AWESOME_INDUSTRY='f275'
CODEPOINT_OF_AWESOME_INFO='f129'
CODEPOINT_OF_AWESOME_INFO_CIRCLE='f05a'
CODEPOINT_OF_AWESOME_INR='f156'
CODEPOINT_OF_AWESOME_INSTAGRAM='f16d'
CODEPOINT_OF_AWESOME_INSTITUTION='f19c'
CODEPOINT_OF_AWESOME_INTERNET_EXPLORER='f26b'
CODEPOINT_OF_AWESOME_INTERSEX='f224'
CODEPOINT_OF_AWESOME_IOXHOST='f208'
CODEPOINT_OF_AWESOME_ITALIC='f033'
CODEPOINT_OF_AWESOME_JOOMLA='f1aa'
CODEPOINT_OF_AWESOME_JPY='f157'
CODEPOINT_OF_AWESOME_JSFIDDLE='f1cc'
CODEPOINT_OF_AWESOME_KEY='f084'
CODEPOINT_OF_AWESOME_KEYBOARD_O='f11c'
CODEPOINT_OF_AWESOME_KRW='f159'
CODEPOINT_OF_AWESOME_LANGUAGE='f1ab'
CODEPOINT_OF_AWESOME_LAPTOP='f109'
CODEPOINT_OF_AWESOME_LASTFM='f202'
CODEPOINT_OF_AWESOME_LASTFM_SQUARE='f203'
CODEPOINT_OF_AWESOME_LEAF='f06c'
CODEPOINT_OF_AWESOME_LEANPUB='f212'
CODEPOINT_OF_AWESOME_LEGAL='f0e3'
CODEPOINT_OF_AWESOME_LEMON_O='f094'
CODEPOINT_OF_AWESOME_LEVEL_DOWN='f149'
CODEPOINT_OF_AWESOME_LEVEL_UP='f148'
CODEPOINT_OF_AWESOME_LIFE_BOUY='f1cd'
CODEPOINT_OF_AWESOME_LIFE_BUOY='f1cd'
CODEPOINT_OF_AWESOME_LIFE_RING='f1cd'
CODEPOINT_OF_AWESOME_LIFE_SAVER='f1cd'
CODEPOINT_OF_AWESOME_LIGHTBULB_O='f0eb'
CODEPOINT_OF_AWESOME_LINE_CHART='f201'
CODEPOINT_OF_AWESOME_LINK='f0c1'
CODEPOINT_OF_AWESOME_LINKEDIN='f0e1'
CODEPOINT_OF_AWESOME_LINKEDIN_SQUARE='f08c'
CODEPOINT_OF_AWESOME_LINODE='f2b8'
CODEPOINT_OF_AWESOME_LINUX='f17c'
CODEPOINT_OF_AWESOME_LIST='f03a'
CODEPOINT_OF_AWESOME_LIST_ALT='f022'
CODEPOINT_OF_AWESOME_LIST_OL='f0cb'
CODEPOINT_OF_AWESOME_LIST_UL='f0ca'
CODEPOINT_OF_AWESOME_LOCATION_ARROW='f124'
CODEPOINT_OF_AWESOME_LOCK='f023'
CODEPOINT_OF_AWESOME_LONG_ARROW_DOWN='f175'
CODEPOINT_OF_AWESOME_LONG_ARROW_LEFT='f177'
CODEPOINT_OF_AWESOME_LONG_ARROW_RIGHT='f178'
CODEPOINT_OF_AWESOME_LONG_ARROW_UP='f176'
CODEPOINT_OF_AWESOME_LOW_VISION='f2a8'
CODEPOINT_OF_AWESOME_MAGIC='f0d0'
CODEPOINT_OF_AWESOME_MAGNET='f076'
CODEPOINT_OF_AWESOME_MAIL_FORWARD='f064'
CODEPOINT_OF_AWESOME_MAIL_REPLY='f112'
CODEPOINT_OF_AWESOME_MAIL_REPLY_ALL='f122'
CODEPOINT_OF_AWESOME_MALE='f183'
CODEPOINT_OF_AWESOME_MAP='f279'
CODEPOINT_OF_AWESOME_MAP_MARKER='f041'
CODEPOINT_OF_AWESOME_MAP_O='f278'
CODEPOINT_OF_AWESOME_MAP_PIN='f276'
CODEPOINT_OF_AWESOME_MAP_SIGNS='f277'
CODEPOINT_OF_AWESOME_MARS='f222'
CODEPOINT_OF_AWESOME_MARS_DOUBLE='f227'
CODEPOINT_OF_AWESOME_MARS_STROKE='f229'
CODEPOINT_OF_AWESOME_MARS_STROKE_H='f22b'
CODEPOINT_OF_AWESOME_MARS_STROKE_V='f22a'
CODEPOINT_OF_AWESOME_MAXCDN='f136'
CODEPOINT_OF_AWESOME_MEANPATH='f20c'
CODEPOINT_OF_AWESOME_MEDIUM='f23a'
CODEPOINT_OF_AWESOME_MEDKIT='f0fa'
CODEPOINT_OF_AWESOME_MEETUP='f2e0'
CODEPOINT_OF_AWESOME_MEH_O='f11a'
CODEPOINT_OF_AWESOME_MERCURY='f223'
CODEPOINT_OF_AWESOME_MICROCHIP='f2db'
CODEPOINT_OF_AWESOME_MICROPHONE='f130'
CODEPOINT_OF_AWESOME_MICROPHONE_SLASH='f131'
CODEPOINT_OF_AWESOME_MINUS='f068'
CODEPOINT_OF_AWESOME_MINUS_CIRCLE='f056'
CODEPOINT_OF_AWESOME_MINUS_SQUARE='f146'
CODEPOINT_OF_AWESOME_MINUS_SQUARE_O='f147'
CODEPOINT_OF_AWESOME_MIXCLOUD='f289'
CODEPOINT_OF_AWESOME_MOBILE='f10b'
CODEPOINT_OF_AWESOME_MOBILE_PHONE='f10b'
CODEPOINT_OF_AWESOME_MODX='f285'
CODEPOINT_OF_AWESOME_MONEY='f0d6'
CODEPOINT_OF_AWESOME_MOON_O='f186'
CODEPOINT_OF_AWESOME_MORTAR_BOARD='f19d'
CODEPOINT_OF_AWESOME_MOTORCYCLE='f21c'
CODEPOINT_OF_AWESOME_MOUSE_POINTER='f245'
CODEPOINT_OF_AWESOME_MUSIC='f001'
CODEPOINT_OF_AWESOME_NAVICON='f0c9'
CODEPOINT_OF_AWESOME_NEUTER='f22c'
CODEPOINT_OF_AWESOME_NEWSPAPER_O='f1ea'
CODEPOINT_OF_AWESOME_OBJECT_GROUP='f247'
CODEPOINT_OF_AWESOME_OBJECT_UNGROUP='f248'
CODEPOINT_OF_AWESOME_ODNOKLASSNIKI='f263'
CODEPOINT_OF_AWESOME_ODNOKLASSNIKI_SQUARE='f264'
CODEPOINT_OF_AWESOME_OPENCART='f23d'
CODEPOINT_OF_AWESOME_OPENID='f19b'
CODEPOINT_OF_AWESOME_OPERA='f26a'
CODEPOINT_OF_AWESOME_OPTIN_MONSTER='f23c'
CODEPOINT_OF_AWESOME_OUTDENT='f03b'
CODEPOINT_OF_AWESOME_PAGELINES='f18c'
CODEPOINT_OF_AWESOME_PAINT_BRUSH='f1fc'
CODEPOINT_OF_AWESOME_PAPER_PLANE='f1d8'
CODEPOINT_OF_AWESOME_PAPER_PLANE_O='f1d9'
CODEPOINT_OF_AWESOME_PAPERCLIP='f0c6'
CODEPOINT_OF_AWESOME_PARAGRAPH='f1dd'
CODEPOINT_OF_AWESOME_PASTE='f0ea'
CODEPOINT_OF_AWESOME_PAUSE='f04c'
CODEPOINT_OF_AWESOME_PAUSE_CIRCLE='f28b'
CODEPOINT_OF_AWESOME_PAUSE_CIRCLE_O='f28c'
CODEPOINT_OF_AWESOME_PAW='f1b0'
CODEPOINT_OF_AWESOME_PAYPAL='f1ed'
CODEPOINT_OF_AWESOME_PENCIL='f040'
CODEPOINT_OF_AWESOME_PENCIL_SQUARE='f14b'
CODEPOINT_OF_AWESOME_PENCIL_SQUARE_O='f044'
CODEPOINT_OF_AWESOME_PERCENT='f295'
CODEPOINT_OF_AWESOME_PHONE='f095'
CODEPOINT_OF_AWESOME_PHONE_SQUARE='f098'
CODEPOINT_OF_AWESOME_PHOTO='f03e'
CODEPOINT_OF_AWESOME_PICTURE_O='f03e'
CODEPOINT_OF_AWESOME_PIE_CHART='f200'
CODEPOINT_OF_AWESOME_PIED_PIPER='f2ae'
CODEPOINT_OF_AWESOME_PIED_PIPER_ALT='f1a8'
CODEPOINT_OF_AWESOME_PIED_PIPER_PP='f1a7'
CODEPOINT_OF_AWESOME_PINTEREST='f0d2'
CODEPOINT_OF_AWESOME_PINTEREST_P='f231'
CODEPOINT_OF_AWESOME_PINTEREST_SQUARE='f0d3'
CODEPOINT_OF_AWESOME_PLANE='f072'
CODEPOINT_OF_AWESOME_PLAY='f04b'
CODEPOINT_OF_AWESOME_PLAY_CIRCLE='f144'
CODEPOINT_OF_AWESOME_PLAY_CIRCLE_O='f01d'
CODEPOINT_OF_AWESOME_PLUG='f1e6'
CODEPOINT_OF_AWESOME_PLUS='f067'
CODEPOINT_OF_AWESOME_PLUS_CIRCLE='f055'
CODEPOINT_OF_AWESOME_PLUS_SQUARE='f0fe'
CODEPOINT_OF_AWESOME_PLUS_SQUARE_O='f196'
CODEPOINT_OF_AWESOME_PODCAST='f2ce'
CODEPOINT_OF_AWESOME_POWER_OFF='f011'
CODEPOINT_OF_AWESOME_PRINT='f02f'
CODEPOINT_OF_AWESOME_PRODUCT_HUNT='f288'
CODEPOINT_OF_AWESOME_PUZZLE_PIECE='f12e'
CODEPOINT_OF_AWESOME_QQ='f1d6'
CODEPOINT_OF_AWESOME_QRCODE='f029'
CODEPOINT_OF_AWESOME_QUESTION='f128'
CODEPOINT_OF_AWESOME_QUESTION_CIRCLE='f059'
CODEPOINT_OF_AWESOME_QUESTION_CIRCLE_O='f29c'
CODEPOINT_OF_AWESOME_QUORA='f2c4'
CODEPOINT_OF_AWESOME_QUOTE_LEFT='f10d'
CODEPOINT_OF_AWESOME_QUOTE_RIGHT='f10e'
CODEPOINT_OF_AWESOME_RA='f1d0'
CODEPOINT_OF_AWESOME_RANDOM='f074'
CODEPOINT_OF_AWESOME_RAVELRY='f2d9'
CODEPOINT_OF_AWESOME_REBEL='f1d0'
CODEPOINT_OF_AWESOME_RECYCLE='f1b8'
CODEPOINT_OF_AWESOME_REDDIT='f1a1'
CODEPOINT_OF_AWESOME_REDDIT_ALIEN='f281'
CODEPOINT_OF_AWESOME_REDDIT_SQUARE='f1a2'
CODEPOINT_OF_AWESOME_REFRESH='f021'
CODEPOINT_OF_AWESOME_REGISTERED='f25d'
CODEPOINT_OF_AWESOME_REMOVE='f00d'
CODEPOINT_OF_AWESOME_RENREN='f18b'
CODEPOINT_OF_AWESOME_REORDER='f0c9'
CODEPOINT_OF_AWESOME_REPEAT='f01e'
CODEPOINT_OF_AWESOME_REPLY='f112'
CODEPOINT_OF_AWESOME_REPLY_ALL='f122'
CODEPOINT_OF_AWESOME_RESISTANCE='f1d0'
CODEPOINT_OF_AWESOME_RETWEET='f079'
CODEPOINT_OF_AWESOME_RMB='f157'
CODEPOINT_OF_AWESOME_ROAD='f018'
CODEPOINT_OF_AWESOME_ROCKET='f135'
CODEPOINT_OF_AWESOME_ROTATE_LEFT='f0e2'
CODEPOINT_OF_AWESOME_ROTATE_RIGHT='f01e'
CODEPOINT_OF_AWESOME_ROUBLE='f158'
CODEPOINT_OF_AWESOME_RSS='f09e'
CODEPOINT_OF_AWESOME_RSS_SQUARE='f143'
CODEPOINT_OF_AWESOME_RUB='f158'
CODEPOINT_OF_AWESOME_RUBLE='f158'
CODEPOINT_OF_AWESOME_RUPEE='f156'
CODEPOINT_OF_AWESOME_S15='f2cd'
CODEPOINT_OF_AWESOME_SAFARI='f267'
CODEPOINT_OF_AWESOME_SAVE='f0c7'
CODEPOINT_OF_AWESOME_SCISSORS='f0c4'
CODEPOINT_OF_AWESOME_SCRIBD='f28a'
CODEPOINT_OF_AWESOME_SEARCH='f002'
CODEPOINT_OF_AWESOME_SEARCH_MINUS='f010'
CODEPOINT_OF_AWESOME_SEARCH_PLUS='f00e'
CODEPOINT_OF_AWESOME_SELLSY='f213'
CODEPOINT_OF_AWESOME_SEND='f1d8'
CODEPOINT_OF_AWESOME_SEND_O='f1d9'
CODEPOINT_OF_AWESOME_SERVER='f233'
CODEPOINT_OF_AWESOME_SHARE='f064'
CODEPOINT_OF_AWESOME_SHARE_ALT='f1e0'
CODEPOINT_OF_AWESOME_SHARE_ALT_SQUARE='f1e1'
CODEPOINT_OF_AWESOME_SHARE_SQUARE='f14d'
CODEPOINT_OF_AWESOME_SHARE_SQUARE_O='f045'
CODEPOINT_OF_AWESOME_SHEKEL='f20b'
CODEPOINT_OF_AWESOME_SHEQEL='f20b'
CODEPOINT_OF_AWESOME_SHIELD='f132'
CODEPOINT_OF_AWESOME_SHIP='f21a'
CODEPOINT_OF_AWESOME_SHIRTSINBULK='f214'
CODEPOINT_OF_AWESOME_SHOPPING_BAG='f290'
CODEPOINT_OF_AWESOME_SHOPPING_BASKET='f291'
CODEPOINT_OF_AWESOME_SHOPPING_CART='f07a'
CODEPOINT_OF_AWESOME_SHOWER='f2cc'
CODEPOINT_OF_AWESOME_SIGN_IN='f090'
CODEPOINT_OF_AWESOME_SIGN_LANGUAGE='f2a7'
CODEPOINT_OF_AWESOME_SIGN_OUT='f08b'
CODEPOINT_OF_AWESOME_SIGNAL='f012'
CODEPOINT_OF_AWESOME_SIGNING='f2a7'
CODEPOINT_OF_AWESOME_SIMPLYBUILT='f215'
CODEPOINT_OF_AWESOME_SITEMAP='f0e8'
CODEPOINT_OF_AWESOME_SKYATLAS='f216'
CODEPOINT_OF_AWESOME_SKYPE='f17e'
CODEPOINT_OF_AWESOME_SLACK='f198'
CODEPOINT_OF_AWESOME_SLIDERS='f1de'
CODEPOINT_OF_AWESOME_SLIDESHARE='f1e7'
CODEPOINT_OF_AWESOME_SMILE_O='f118'
CODEPOINT_OF_AWESOME_SNAPCHAT='f2ab'
CODEPOINT_OF_AWESOME_SNAPCHAT_GHOST='f2ac'
CODEPOINT_OF_AWESOME_SNAPCHAT_SQUARE='f2ad'
CODEPOINT_OF_AWESOME_SNOWFLAKE_O='f2dc'
CODEPOINT_OF_AWESOME_SOCCER_BALL_O='f1e3'
CODEPOINT_OF_AWESOME_SORT='f0dc'
CODEPOINT_OF_AWESOME_SORT_ALPHA_ASC='f15d'
CODEPOINT_OF_AWESOME_SORT_ALPHA_DESC='f15e'
CODEPOINT_OF_AWESOME_SORT_AMOUNT_ASC='f160'
CODEPOINT_OF_AWESOME_SORT_AMOUNT_DESC='f161'
CODEPOINT_OF_AWESOME_SORT_ASC='f0de'
CODEPOINT_OF_AWESOME_SORT_DESC='f0dd'
CODEPOINT_OF_AWESOME_SORT_DOWN='f0dd'
CODEPOINT_OF_AWESOME_SORT_NUMERIC_ASC='f162'
CODEPOINT_OF_AWESOME_SORT_NUMERIC_DESC='f163'
CODEPOINT_OF_AWESOME_SORT_UP='f0de'
CODEPOINT_OF_AWESOME_SOUNDCLOUD='f1be'
CODEPOINT_OF_AWESOME_SPACE_SHUTTLE='f197'
CODEPOINT_OF_AWESOME_SPINNER='f110'
CODEPOINT_OF_AWESOME_SPOON='f1b1'
CODEPOINT_OF_AWESOME_SPOTIFY='f1bc'
CODEPOINT_OF_AWESOME_SQUARE='f0c8'
CODEPOINT_OF_AWESOME_SQUARE_O='f096'
CODEPOINT_OF_AWESOME_STACK_EXCHANGE='f18d'
CODEPOINT_OF_AWESOME_STACK_OVERFLOW='f16c'
CODEPOINT_OF_AWESOME_STAR='f005'
CODEPOINT_OF_AWESOME_STAR_HALF='f089'
CODEPOINT_OF_AWESOME_STAR_HALF_EMPTY='f123'
CODEPOINT_OF_AWESOME_STAR_HALF_FULL='f123'
CODEPOINT_OF_AWESOME_STAR_HALF_O='f123'
CODEPOINT_OF_AWESOME_STAR_O='f006'
CODEPOINT_OF_AWESOME_STEAM='f1b6'
CODEPOINT_OF_AWESOME_STEAM_SQUARE='f1b7'
CODEPOINT_OF_AWESOME_STEP_BACKWARD='f048'
CODEPOINT_OF_AWESOME_STEP_FORWARD='f051'
CODEPOINT_OF_AWESOME_STETHOSCOPE='f0f1'
CODEPOINT_OF_AWESOME_STICKY_NOTE='f249'
CODEPOINT_OF_AWESOME_STICKY_NOTE_O='f24a'
CODEPOINT_OF_AWESOME_STOP='f04d'
CODEPOINT_OF_AWESOME_STOP_CIRCLE='f28d'
CODEPOINT_OF_AWESOME_STOP_CIRCLE_O='f28e'
CODEPOINT_OF_AWESOME_STREET_VIEW='f21d'
CODEPOINT_OF_AWESOME_STRIKETHROUGH='f0cc'
CODEPOINT_OF_AWESOME_STUMBLEUPON='f1a4'
CODEPOINT_OF_AWESOME_STUMBLEUPON_CIRCLE='f1a3'
CODEPOINT_OF_AWESOME_SUBSCRIPT='f12c'
CODEPOINT_OF_AWESOME_SUBWAY='f239'
CODEPOINT_OF_AWESOME_SUITCASE='f0f2'
CODEPOINT_OF_AWESOME_SUN_O='f185'
CODEPOINT_OF_AWESOME_SUPERPOWERS='f2dd'
CODEPOINT_OF_AWESOME_SUPERSCRIPT='f12b'
CODEPOINT_OF_AWESOME_SUPPORT='f1cd'
CODEPOINT_OF_AWESOME_TABLE='f0ce'
CODEPOINT_OF_AWESOME_TABLET='f10a'
CODEPOINT_OF_AWESOME_TACHOMETER='f0e4'
CODEPOINT_OF_AWESOME_TAG='f02b'
CODEPOINT_OF_AWESOME_TAGS='f02c'
CODEPOINT_OF_AWESOME_TASKS='f0ae'
CODEPOINT_OF_AWESOME_TAXI='f1ba'
CODEPOINT_OF_AWESOME_TELEGRAM='f2c6'
CODEPOINT_OF_AWESOME_TELEVISION='f26c'
CODEPOINT_OF_AWESOME_TENCENT_WEIBO='f1d5'
CODEPOINT_OF_AWESOME_TERMINAL='f120'
CODEPOINT_OF_AWESOME_TEXT_HEIGHT='f034'
CODEPOINT_OF_AWESOME_TEXT_WIDTH='f035'
CODEPOINT_OF_AWESOME_TH='f00a'
CODEPOINT_OF_AWESOME_TH_LARGE='f009'
CODEPOINT_OF_AWESOME_TH_LIST='f00b'
CODEPOINT_OF_AWESOME_THEMEISLE='f2b2'
CODEPOINT_OF_AWESOME_THERMOMETER='f2c7'
CODEPOINT_OF_AWESOME_THERMOMETER_0='f2cb'
CODEPOINT_OF_AWESOME_THERMOMETER_1='f2ca'
CODEPOINT_OF_AWESOME_THERMOMETER_2='f2c9'
CODEPOINT_OF_AWESOME_THERMOMETER_3='f2c8'
CODEPOINT_OF_AWESOME_THERMOMETER_4='f2c7'
CODEPOINT_OF_AWESOME_THERMOMETER_EMPTY='f2cb'
CODEPOINT_OF_AWESOME_THERMOMETER_FULL='f2c7'
CODEPOINT_OF_AWESOME_THERMOMETER_HALF='f2c9'
CODEPOINT_OF_AWESOME_THERMOMETER_QUARTER='f2ca'
CODEPOINT_OF_AWESOME_THERMOMETER_THREE_QUARTERS='f2c8'
CODEPOINT_OF_AWESOME_THUMB_TACK='f08d'
CODEPOINT_OF_AWESOME_THUMBS_DOWN='f165'
CODEPOINT_OF_AWESOME_THUMBS_O_DOWN='f088'
CODEPOINT_OF_AWESOME_THUMBS_O_UP='f087'
CODEPOINT_OF_AWESOME_THUMBS_UP='f164'
CODEPOINT_OF_AWESOME_TICKET='f145'
CODEPOINT_OF_AWESOME_TIMES='f00d'
CODEPOINT_OF_AWESOME_TIMES_CIRCLE='f057'
CODEPOINT_OF_AWESOME_TIMES_CIRCLE_O='f05c'
CODEPOINT_OF_AWESOME_TIMES_RECTANGLE='f2d3'
CODEPOINT_OF_AWESOME_TIMES_RECTANGLE_O='f2d4'
CODEPOINT_OF_AWESOME_TINT='f043'
CODEPOINT_OF_AWESOME_TOGGLE_DOWN='f150'
CODEPOINT_OF_AWESOME_TOGGLE_LEFT='f191'
CODEPOINT_OF_AWESOME_TOGGLE_OFF='f204'
CODEPOINT_OF_AWESOME_TOGGLE_ON='f205'
CODEPOINT_OF_AWESOME_TOGGLE_RIGHT='f152'
CODEPOINT_OF_AWESOME_TOGGLE_UP='f151'
CODEPOINT_OF_AWESOME_TRADEMARK='f25c'
CODEPOINT_OF_AWESOME_TRAIN='f238'
CODEPOINT_OF_AWESOME_TRANSGENDER='f224'
CODEPOINT_OF_AWESOME_TRANSGENDER_ALT='f225'
CODEPOINT_OF_AWESOME_TRASH='f1f8'
CODEPOINT_OF_AWESOME_TRASH_O='f014'
CODEPOINT_OF_AWESOME_TREE='f1bb'
CODEPOINT_OF_AWESOME_TRELLO='f181'
CODEPOINT_OF_AWESOME_TRIPADVISOR='f262'
CODEPOINT_OF_AWESOME_TROPHY='f091'
CODEPOINT_OF_AWESOME_TRUCK='f0d1'
CODEPOINT_OF_AWESOME_TRY='f195'
CODEPOINT_OF_AWESOME_TTY='f1e4'
CODEPOINT_OF_AWESOME_TUMBLR='f173'
CODEPOINT_OF_AWESOME_TUMBLR_SQUARE='f174'
CODEPOINT_OF_AWESOME_TURKISH_LIRA='f195'
CODEPOINT_OF_AWESOME_TV='f26c'
CODEPOINT_OF_AWESOME_TWITCH='f1e8'
CODEPOINT_OF_AWESOME_TWITTER='f099'
CODEPOINT_OF_AWESOME_TWITTER_SQUARE='f081'
CODEPOINT_OF_AWESOME_UMBRELLA='f0e9'
CODEPOINT_OF_AWESOME_UNDERLINE='f0cd'
CODEPOINT_OF_AWESOME_UNDO='f0e2'
CODEPOINT_OF_AWESOME_UNIVERSAL_ACCESS='f29a'
CODEPOINT_OF_AWESOME_UNIVERSITY='f19c'
CODEPOINT_OF_AWESOME_UNLINK='f127'
CODEPOINT_OF_AWESOME_UNLOCK='f09c'
CODEPOINT_OF_AWESOME_UNLOCK_ALT='f13e'
CODEPOINT_OF_AWESOME_UNSORTED='f0dc'
CODEPOINT_OF_AWESOME_UPLOAD='f093'
CODEPOINT_OF_AWESOME_USB='f287'
CODEPOINT_OF_AWESOME_USD='f155'
CODEPOINT_OF_AWESOME_USER='f007'
CODEPOINT_OF_AWESOME_USER_CIRCLE='f2bd'
CODEPOINT_OF_AWESOME_USER_CIRCLE_O='f2be'
CODEPOINT_OF_AWESOME_USER_MD='f0f0'
CODEPOINT_OF_AWESOME_USER_O='f2c0'
CODEPOINT_OF_AWESOME_USER_PLUS='f234'
CODEPOINT_OF_AWESOME_USER_SECRET='f21b'
CODEPOINT_OF_AWESOME_USER_TIMES='f235'
CODEPOINT_OF_AWESOME_USERS='f0c0'
CODEPOINT_OF_AWESOME_VCARD='f2bb'
