OCTICONS_GLYPHS_LOADED=1
OCTICONS_GLYPHS_VERSION='1.0.0'
CODEPOINT_OF_OCTICONS_HEART='f300'
CODEPOINT_OF_OCTICONS_ZAP='f301'
CODEPOINT_OF_OCTICONS_LIGHT_BULB='f302'
CODEPOINT_OF_OCTICONS_REPO='f303'
CODEPOINT_OF_OCTICONS_REPO_FORKED='f304'
CODEPOINT_OF_OCTICONS_REPO_CREATE='f305'
CODEPOINT_OF_OCTICONS_REPO_DELETE='f306'
CODEPOINT_OF_OCTICONS_REPO_PUSH='f307'
CODEPOINT_OF_OCTICONS_REPO_PULL='f308'
CODEPOINT_OF_OCTICONS_BOOK='f309'
CODEPOINT_OF_OCTICONS_OCTOFACE='f30a'
CODEPOINT_OF_OCTICONS_GIT_PULL_REQUEST='f30b'
CODEPOINT_OF_OCTICONS_MARK_GITHUB='f30c'
CODEPOINT_OF_OCTICONS_CLOUD_DOWNLOAD='f30d'
CODEPOINT_OF_OCTICONS_CLOUD_UPLOAD='f30e'
CODEPOINT_OF_OCTICONS_KEYBOARD='f30f'
CODEPOINT_OF_OCTICONS_GIST='f310'
CODEPOINT_OF_OCTICONS_GIST_PRIVATE='f311'
CODEPOINT_OF_OCTICONS_FILE_CODE='f312'
CODEPOINT_OF_OCTICONS_FILE_TEXT='f313'
CODEPOINT_OF_OCTICONS_FILE_MEDIA='f314'
CODEPOINT_OF_OCTICONS_FILE_ZIP='f315'
CODEPOINT_OF_OCTICONS_FILE_PDF='f316'
CODEPOINT_OF_OCTICONS_TAG='f317'
CODEPOINT_OF_OCTICONS_FILE_DIRECTORY='f318'
CODEPOINT_OF_OCTICONS_FILE_SUBMODULE='f319'
CODEPOINT_OF_OCTICONS_PERSON='f31a'
CODEPOINT_OF_OCTICONS_JERSEY='f31b'
CODEPOINT_OF_OCTICONS_PERSON_ADD='f31c'
CODEPOINT_OF_OCTICONS_PERSON_REMOVE='f31d'
CODEPOINT_OF_OCTICONS_PERSON_FOLLOW='f31e'
CODEPOINT_OF_OCTICONS_EYE_WATCH='f31f'
CODEPOINT_OF_OCTICONS_EYE_UNWATCH='f320'
CODEPOINT_OF_OCTICONS_GIT_COMMIT='f321'
CODEPOINT_OF_OCTICONS_GIT_BRANCH='f322'
CODEPOINT_OF_OCTICONS_GIT_FORK_PRIVATE='f323'
CODEPOINT_OF_OCTICONS_GIT_MERGE='f324'
CODEPOINT_OF_OCTICONS_MIRROR_PUBLIC='f325'
CODEPOINT_OF_OCTICONS_MIRROR_PRIVATE='f326'
CODEPOINT_OF_OCTICONS_ISSUE_OPENED='f327'
CODEPOINT_OF_OCTICONS_ISSUE_REOPENED='f328'
CODEPOINT_OF_OCTICONS_ISSUE_CLOSED='f329'
CODEPOINT_OF_OCTICONS_STAR='f32a'
CODEPOINT_OF_OCTICONS_COMMENT='f32b'
CODEPOINT_OF_OCTICONS_QUESTION='f32c'
CODEPOINT_OF_OCTICONS_ALERT='f32d'
CODEPOINT_OF_OCTICONS_SEARCH='f32e'
CODEPOINT_OF_OCTICONS_GEAR='f32f'
CODEPOINT_OF_OCTICONS_RADIO_TOWER='f330'
CODEPOINT_OF_OCTICONS_TOOLS='f331'
CODEPOINT_OF_OCTICONS_LOG_OUT='f332'
CODEPOINT_OF_OCTICONS_ROCKET='f333'
CODEPOINT_OF_OCTICONS_RSS='f334'
CODEPOINT_OF_OCTICONS_CLIPPY='f335'
CODEPOINT_OF_OCTICONS_LOG_IN='f336'
CODEPOINT_OF_OCTICONS_ORGANIZATION='f337'
CODEPOINT_OF_OCTICONS_DEVICE_MOBILE='f338'
CODEPOINT_OF_OCTICONS_UNFOLD='f339'
CODEPOINT_OF_OCTICONS_CHECK='f33a'
CODEPOINT_OF_OCTICONS_MAIL='f33b'
CODEPOINT_OF_OCTICONS_MAIL_READ='f33c'
CODEPOINT_OF_OCTICONS_ARROW_UP='f33d'
CODEPOINT_OF_OCTICONS_ARROW_RIGHT='f33e'
CODEPOINT_OF_OCTICONS_ARROW_DOWN='f33f'
CODEPOINT_OF_OCTICONS_ARROW_LEFT='f340'
CODEPOINT_OF_OCTICONS_PIN='f341'
CODEPOINT_OF_OCTICONS_GIFT='f342'
CODEPOINT_OF_OCTICONS_GRAPH='f343'
CODEPOINT_OF_OCTICONS_TRIANGLE_LEFT='f344'
CODEPOINT_OF_OCTICONS_CREDIT_CARD='f345'
CODEPOINT_OF_OCTICONS_CLOCK='f346'
CODEPOINT_OF_OCTICONS_RUBY='f347'
CODEPOINT_OF_OCTICONS_BROADCAST='f348'
CODEPOINT_OF_OCTICONS_KEY='f349'
CODEPOINT_OF_OCTICONS_REPO_FORCE_PUSH='f34a'
CODEPOINT_OF_OCTICONS_REPO_SYNC='f34b'
CODEPOINT_OF_OCTICONS_REPO_CLONE='f34c'
CODEPOINT_OF_OCTICONS_DIFF='f34d'
CODEPOINT_OF_OCTICONS_EYE='f34e'
CODEPOINT_OF_OCTICONS_COMMENT_DISCUSSION='f34f'
CODEPOINT_OF_OCTICONS_REMOVE_CLOSE='f350'
CODEPOINT_OF_OCTICONS_MAIL_REPLY='f351'
CODEPOINT_OF_OCTICONS_PRIMITIVE_DOT='f352'
CODEPOINT_OF_OCTICONS_PRIMITIVE_SQUARE='f353'
CODEPOINT_OF_OCTICONS_TAG_ADD='f354'
CODEPOINT_OF_OCTICONS_TAG_REMOVE='f355'
CODEPOINT_OF_OCTICONS_DEVICE_CAMERA='f356'
CODEPOINT_OF_OCTICONS_DEVICE_CAMERA_VIDEO='f357'
CODEPOINT_OF_OCTICONS_PENCIL='f358'
CODEPOINT_OF_OCTICONS_INFO='f359'
CODEPOINT_OF_OCTICONS_TRIANGLE_RIGHT='f35a'
CODEPOINT_OF_OCTICONS_TRIANGLE_DOWN='f35b'
CODEPOINT_OF_OCTICONS_LINK='f35c'
CODEPOINT_OF_OCTICONS_PLUS='f35d'
CODEPOINT_OF_OCTICONS_THREE_BARS='f35e'
CODEPOINT_OF_OCTICONS_CODE='f35f'
CODEPOINT_OF_OCTICONS_LOCATION='f360'
CODEPOINT_OF_OCTICONS_LIST_UNORDERED='f361'
CODEPOINT_OF_OCTICONS_LIST_ORDERED='f362'
CODEPOINT_OF_OCTICONS_QUOTE='f363'
CODEPOINT_OF_OCTICONS_VERSIONS='f364'
CODEPOINT_OF_OCTICONS_COLOR_MODE='f365'
CODEPOINT_OF_OCTICONS_SCREEN_FULL='f366'
CODEPOINT_OF_OCTICONS_SCREEN_NORMAL='f367'
CODEPOINT_OF_OCTICONS_CALENDAR='f368'
CODEPOINT_OF_OCTICONS_BEER='f369'
CODEPOINT_OF_OCTICONS_LOCK='f36a'
CODEPOINT_OF_OCTICONS_DIFF_ADDED='f36b'
CODEPOINT_OF_OCTICONS_DIFF_REMOVED='f36c'
CODEPOINT_OF_OCTICONS_DIFF_MODIFIED='f36d'
CODEPOINT_OF_OCTICONS_DIFF_RENAMED='f36e'
CODEPOINT_OF_OCTICONS_COMMENT_ADD='f36f'
CODEPOINT_OF_OCTICONS_HORIZONTAL_RULE='f370'
CODEPOINT_OF_OCTICONS_ARROW_SMALL_RIGHT='f371'
CODEPOINT_OF_OCTICONS_JUMP_DOWN='f372'
CODEPOINT_OF_OCTICONS_JUMP_UP='f373'
CODEPOINT_OF_OCTICONS_MOVE_LEFT='f374'
CODEPOINT_OF_OCTICONS_MILESTONE='f375'
CODEPOINT_OF_OCTICONS_CHECKLIST='f376'
CODEPOINT_OF_OCTICONS_MEGAPHONE='f377'
CODEPOINT_OF_OCTICONS_CHEVRON_RIGHT='f378'
CODEPOINT_OF_OCTICONS_GIST_FORK='f379'
CODEPOINT_OF_OCTICONS_GIST_NEW='f37a'
CODEPOINT_OF_OCTICONS_BOOKMARK='f37b'
CODEPOINT_OF_OCTICONS_SETTINGS='f37c'
CODEPOINT_OF_OCTICONS_DASHBOARD='f37d'
CODEPOINT_OF_OCTICONS_HISTORY='f37e'
CODEPOINT_OF_OCTICONS_LINK_EXTERNAL='f37f'
CODEPOINT_OF_OCTICONS_MUTE='f380'
CODEPOINT_OF_OCTICONS_X='f381'
CODEPOINT_OF_OCTICONS_STAR_ADD='f382'
CODEPOINT_OF_OCTICONS_STAR_DELETE='f383'
CODEPOINT_OF_OCTICONS_CIRCLE_SLASH='f384'
CODEPOINT_OF_OCTICONS_PULSE='f385'
CODEPOINT_OF_OCTICONS_FILE_ADD='f386'
CODEPOINT_OF_OCTICONS_SYNC='f387'
CODEPOINT_OF_OCTICONS_TELESCOPE='f388'
CODEPOINT_OF_OCTICONS_MICROSCOPE='f389'
CODEPOINT_OF_OCTICONS_ALIGNMENT_ALIGN='f38a'
CODEPOINT_OF_OCTICONS_ALIGNMENT_UNALIGN='f38b'
CODEPOINT_OF_OCTICONS_GIST_SECRET='f38c'
CODEPOINT_OF_OCTICONS_HOME='f38d'
CODEPOINT_OF_OCTICONS_ALIGNMENT_ALIGNED_TO='f38e'
CODEPOINT_OF_OCTICONS_STOP='f38f'
CODEPOINT_OF_OCTICONS_GIT_PULL_REQUEST_ABANDONED='f390'
CODEPOINT_OF_OCTICONS_BUG='f391'
CODEPOINT_OF_OCTICONS_LOGO_GITHUB='f392'
CODEPOINT_OF_OCTICONS_FILE_BINARY='f393'
CODEPOINT_OF_OCTICONS_FILE_DIRECTORY_CREATE='f394'
CODEPOINT_OF_OCTICONS_DATABASE='f395'
CODEPOINT_OF_OCTICONS_SERVER='f396'
CODEPOINT_OF_OCTICONS_GIT_BRANCH_CREATE='f397'
CODEPOINT_OF_OCTICONS_DIFF_IGNORED='f398'
CODEPOINT_OF_OCTICONS_ELLIPSIS='f399'
CODEPOINT_OF_OCTICONS_GIT_BRANCH_DELETE='f39a'
CODEPOINT_OF_OCTICONS_NO_NEWLINE='f39b'
CODEPOINT_OF_OCTICONS_HUBOT='f39c'
CODEPOINT_OF_OCTICONS_HOURGLASS='f39d'
CODEPOINT_OF_OCTICONS_ARROW_SMALL_UP='f39e'
CODEPOINT_OF_OCTICONS_ARROW_SMALL_DOWN='f39f'
CODEPOINT_OF_OCTICONS_ARROW_SMALL_LEFT='f3a0'
CODEPOINT_OF_OCTICONS_CHEVRON_UP='f3a1'
CODEPOINT_OF_OCTICONS_CHEVRON_DOWN='f3a2'
CODEPOINT_OF_OCTICONS_CHEVRON_LEFT='f3a3'
CODEPOINT_OF_OCTICONS_JUMP_LEFT='f3a4'
CODEPOINT_OF_OCTICONS_JUMP_RIGHT='f3a5'
CODEPOINT_OF_OCTICONS_MOVE_UP='f3a6'
CODEPOINT_OF_OCTICONS_MOVE_DOWN='f3a7'
CODEPOINT_OF_OCTICONS_MOVE_RIGHT='f3a8'
CODEPOINT_OF_OCTICONS_TRIANGLE_UP='f3a9'
CODEPOINT_OF_OCTICONS_GIT_COMPARE='f3aa'
CODEPOINT_OF_OCTICONS_MARK_TWITTER='f3ab'
CODEPOINT_OF_OCTICONS_PODIUM='f3ac'
CODEPOINT_OF_OCTICONS_FILE_SYMLINK_FILE='f3ad'
CODEPOINT_OF_OCTICONS_FILE_SYMLINK_DIRECTORY='f3ae'
CODEPOINT_OF_OCTICONS_SQUIRREL='f3af'
CODEPOINT_OF_OCTICONS_GLOBE='f3b0'
CODEPOINT_OF_OCTICONS_MUTE_VIDEO='f3b1'
CODEPOINT_OF_OCTICONS_UNMUTE_VIDEO='f3b2'
CODEPOINT_OF_OCTICONS_UNMUTE='f3b3'
CODEPOINT_OF_OCTICONS_PLAYBACK_PAUSE='f3b4'
CODEPOINT_OF_OCTICONS_PLAYBACK_REWIND='f3b5'
CODEPOINT_OF_OCTICONS_PLAYBACK_FAST_FORWARD='f3b6'
CODEPOINT_OF_OCTICONS_MENTION='f3b7'
CODEPOINT_OF_OCTICONS_PLAYBACK_PLAY='f3b8'
CODEPOINT_OF_OCTICONS_PUZZLE='f3b9'
CODEPOINT_OF_OCTICONS_PACKAGE='f3ba'
CODEPOINT_OF_OCTICONS_BROWSER='f3bb'
CODEPOINT_OF_OCTICONS_SPLIT='f3bc'
CODEPOINT_OF_OCTICONS_STEPS='f3bd'
CODEPOINT_OF_OCTICONS_TERMINAL='f3be'
CODEPOINT_OF_OCTICONS_MARKDOWN='f3bf'
CODEPOINT_OF_OCTICONS_DASH='f3c0'
CODEPOINT_OF_OCTICONS_SEARCH_SAVE='f3c1'
CODEPOINT_OF_OCTICONS_FOLD='f3c2'
CODEPOINT_OF_OCTICONS_MARK_GOOGLE='f3c3'
CODEPOINT_OF_OCTICONS_MARK_FACEBOOK='f3c4'
CODEPOINT_OF_OCTICONS_INBOX='f3c5'
CODEPOINT_OF_OCTICONS_TRASHCAN='f3c6'
CODEPOINT_OF_OCTICONS_PAINTCAN='f3c7'
CODEPOINT_OF_OCTICONS_FLAME='f3c8'
CODEPOINT_OF_OCTICONS_BRIEFCASE='f3c9'
CODEPOINT_OF_OCTICONS_PLUG='f3ca'
CODEPOINT_OF_OCTICONS_DEVICE_DESKTOP='f3cb'
